@@ -82,17 +82,22 @@ def get_one_vec(**kwargs):
     text = kwargs.get('text', '默认')
     is_lite = kwargs.get('is_lite', '0')
 
-    doc = cache_bert.find_one({'text': text, 'is_lite': is_lite})
+    doc = cache_bert.find_one({'text': text})
+
     if doc:
         logger.info(f'dup key: {text}')
-        return [doc['vector']]
+        vecs = doc['vector']
     else:
         vecs = text2vec(text)
-        if is_lite == '1':
-            vecs = vecs[:, range(0, 768, 4)]  # 64*3 = 192维度
         vecs = normalize(vecs).tolist()
-        cache_bert.insert_one({'text': text, 'is_lite': is_lite, 'vector': vecs[0]})
+
+        cache_bert.insert_one({'text': text, 'vector': vecs})
+
+    if is_lite == '0':
         return vecs
+    else:
+        vecs = np.array(vecs)[:, range(0, 768, 4)]
+        return normalize(vecs).tolist()  # 64*3 = 192维度
 
 
 def get_batch_vec(**kwargs):
@@ -107,9 +112,9 @@ def get_batch_vec(**kwargs):
     return normalize(vecs).tolist()
 
 
-logger.info(f"初始化模型: {text2vec('语言模型')}")  # 不初始化会报线程错误
-
 if __name__ == '__main__':
+    logger.info(f"初始化初始化模型: {text2vec('语言模型')}")  # 不初始化会报线程错误
+
     app = App(verbose=os.environ.get('verbose'))
 
     app.add_route('/simbert', get_one_vec, result_key='vectors')
